Change Log
=============

[1.0.1] - 2021-09-10
---------------------

- [FIXED] updated _init_.py

[1.0.0] - 2024-09-09
---------------------

- [CHANGED] included metadata in pyproject.toml and also requirements  (only pyomo, matplotlib, numpy, pandas, and psutil.)
- [CHANGED] created a README.md file
- [FIXED] updated _init_.py
